<?php
/**
 * Класс генерации аватара
 *
 * @link https://lazydev.pro/
 * @author LazyDev <email@lazydev.pro>
 **/

namespace LazyDev\Avatar;

class Avatar
{
    static $mod_config = [], $typeImg = [1 => 'svg', 2 => 'jpg', 3 => 'png'], $userData = [];
    static $avatarFile = ROOT_DIR . '/uploads/fotos/', $avatarUrl = 'uploads/fotos/';

    /**
     * Инициализация модуля
     *
     * @param   array    $userData
     *
     * @return  string
     */
    static function load($userData)
    {
        if (!is_writable(ROOT_DIR . '/uploads/fotos/')) {
            return '';
        }
        
        self::$userData = $userData;
        self::$mod_config = Data::receive('config');
        
        // Защита от людей
        if (!self::$mod_config['color']['bg'][0]) {
            return '';
        }
        
        // Возврат аватара для гостей
        if (($avatar = self::getAvatar()) !== '') {
            return $avatar;
        }

        if (self::$mod_config['turn_on']) {
            // Проверка на группу пользователей
            if (
                !self::$mod_config['gen_group'] ||
                self::$mod_config['gen_group'] && in_array(self::$userData['user_group'], self::$mod_config['gen_group'])
            ) {
                return self::setAvatar();
            }
        }

        return '';
    }

    /**
     * Возврат аватара
     *
     * @return  string
     */
    static function getAvatar()
    {
        global $config;

        $id = self::$userData['gast_name'] ? md5(self::$userData['gast_name']) : self::$userData['user_id'];
        $url = self::$avatarFile . 'foto_' . $id . '.' . self::$typeImg[self::$mod_config['type_img']];
        if (file_exists($url)) {
            $avatar = $config['http_home_url'] . self::$avatarUrl . 'foto_' . $id . '.' . self::$typeImg[self::$mod_config['type_img']];
            return $avatar;
        }

        return '';
    }

    /**
     * Создание аватара
     *
     * @return  string
     */
    static function setAvatar()
    {
        $avatar = '';
        switch (self::$mod_config['type_img']) {
            case 1:
                $avatar = self::svg();
                break;
            case 2:
                $avatar = self::jpg();
                break;
            case 3:
                $avatar = self::png();
                break;
        }

        return $avatar;
    }

    /**
     * Получение ника
     *
     * @return  string
     */
    static function name()
    {
        $name = self::$userData['gast_name'] ? self::$userData['gast_name'] : self::$userData['name'];
        if ($name) {
            return mb_strtoupper($name{0} . $name{mb_strlen($name)-1}, 'UTF-8');
        }

        return '';
    }

    /**
     * SVG аватар
     *
     * @return  string
     */
    static function svg()
    {
        $fillImg = 'img_circle.svg';
        if (self::$mod_config['fill_img'] == 2) {
            $fillImg = 'img_rect.svg';
        }

        // Берем файл
        $svg = file_get_contents(ENGINE_DIR . '/lazydev/avatar_gen/res/' . $fillImg);

        // Имя
        $getName = self::name();
        $svg = str_replace('NICK_USER', $getName, $svg);

        // Цвет заливки
        $keyColor = array_rand(self::$mod_config['color']['bg'], 1);
        $colorBg = self::$mod_config['color']['bg'][$keyColor];
        $svg = str_replace('FILL_COLOR', '#' . $colorBg, $svg);

        // Цвет текста
        $colorFont = self::$mod_config['color']['font'][$keyColor];
        $svg = str_replace('TEXT_COLOR', '#' . $colorFont, $svg);

        if (self::$userData['user_group'] === NULL) {
            self::saveAvatarGuest($svg);
        } else {
            self::saveAvatarUser($svg);
        }

        return self::getAvatar();
    }

    /**
     * HEX в RGB
     *
     * @param   string    $color
     *
     * @return  array
     */
    static function hexToRgb($color)
    {
        $length = strlen($color);
        $rgb = [];
        $rgb['r'] = hexdec($length == 6 ? substr($color, 0, 2) : ($length == 3 ? str_repeat(substr($color, 0, 1), 2) : 0));
        $rgb['g'] = hexdec($length == 6 ? substr($color, 2, 2) : ($length == 3 ? str_repeat(substr($color, 1, 1), 2) : 0));
        $rgb['b'] = hexdec($length == 6 ? substr($color, 4, 2) : ($length == 3 ? str_repeat(substr($color, 2, 1), 2) : 0));
        return $rgb;
    }

    /**
     * JPG аватар
     *
     * @return  string
     */
    static function jpg()
    {
        // Имя
        $getName = self::name();

        // Цвет заливки
        $keyColor = array_rand(self::$mod_config['color']['bg'], 1);
        $colorBg = self::$mod_config['color']['bg'][$keyColor];
        $colorBg = self::hexToRgb($colorBg);

        // Цвет текста
        $colorFont = self::$mod_config['color']['font'][$keyColor];
        $colorFont = self::hexToRgb($colorFont);

        // Создание аватарки
        $image = imagecreatetruecolor(100, 100);

        // Заливка фона
        $fillBg = imagecolorallocate($image, $colorBg['r'], $colorBg['g'], $colorBg['b']);
        if (self::$mod_config['fill_img'] == 2) {
            imagefilledrectangle($image, 0, 0, 0, 0, $fillBg);
        } else {
            imagefilledellipse($image, 50, 50, 100, 100, $fillBg);
        }

        // Цвет текста
        $colorText = imagecolorallocate($image, $colorFont['r'], $colorFont['g'], $colorFont['b']);

        // Шрифт
        $font = ENGINE_DIR . '/lazydev/avatar_gen/res/Arial.ttf';

        // Центрирование текста
        $ttfBox = imagettfbbox(32, 0, $font, $getName);
        $centerX = (imagesx($image) / 2) - (($ttfBox[2] - $ttfBox[0]) / 2);
        $centerY = (imagesx($image) / 2) - (($ttfBox[5] - $ttfBox[1]) / 2);

        // Надпись
        imagettftext($image, 32, 0, $centerX, $centerY, $colorText, $font, $getName);

        ob_start();
        imagejpeg($image, NULL, 100);
        $avatar = ob_get_contents();
        imagedestroy($image);
        ob_end_clean();

        if (self::$userData['user_group'] === NULL) {
            self::saveAvatarGuest($avatar);
        } else {
            self::saveAvatarUser($avatar);
        }

        return self::getAvatar();
    }

    /**
     * PNG аватар
     *
     * @return  string
     */
    static function png()
    {

        // Имя
        $getName = self::name();

        // Цвет заливки
        $keyColor = array_rand(self::$mod_config['color']['bg'], 1);
        $colorBg = self::$mod_config['color']['bg'][$keyColor];
        $colorBg = self::hexToRgb($colorBg);

        // Цвет текста
        $colorFont = self::$mod_config['color']['font'][$keyColor];
        $colorFont = self::hexToRgb($colorFont);

        // Создание аватарки
        $image = imagecreatetruecolor(100, 100);

        // Заливка фона
        $fillBg = imagecolorallocate($image, $colorBg['r'], $colorBg['g'], $colorBg['b']);
        if (self::$mod_config['fill_img'] == 2) {
            imagefill($image, 0, 0, $fillBg);
        } else {
            imagesavealpha($image, true);
            $color = imagecolorallocatealpha($image, 0, 0, 0, 127);
            imagefill($image, 0, 0, $color);
            imagefilledellipse($image, 50, 50, 100, 100, $fillBg);
        }

        // Цвет текста
        $colorText = imagecolorallocate($image, $colorFont['r'], $colorFont['g'], $colorFont['b']);

        // Шрифт
        $font = ENGINE_DIR . '/lazydev/avatar_gen/res/Arial.ttf';

        // Центрирование текста
        $ttfBox = imagettfbbox(32, 0, $font, $getName);
        $centerX = (imagesx($image) / 2) - (($ttfBox[2] - $ttfBox[0]) / 2);
        $centerY = (imagesx($image) / 2) - (($ttfBox[5] - $ttfBox[1]) / 2);

        // Надпись
        imagettftext($image, 32, 0, $centerX, $centerY, $colorText, $font, $getName);

        ob_start();
        imagepng($image);
        $avatar = ob_get_contents();
        imagedestroy($image);
        ob_end_clean();

        if (self::$userData['user_group'] === NULL) {
            self::saveAvatarGuest($avatar);
        } else {
            self::saveAvatarUser($avatar);
        }

        return self::getAvatar();
    }

    /**
     * Сохранение аватара для пользователя
     *
     * @param   string    $avatar
     */
    static function saveAvatarUser($avatar)
    {
        global $db, $config;

        $avatarName = 'foto_' . self::$userData['user_id'] . '.' . self::$typeImg[self::$mod_config['type_img']];
        $avatarUser = str_replace(['https:', 'http:'], '', $config['http_home_url']) . self::$avatarUrl . $avatarName;
        $db->query("UPDATE " . USERPREFIX . "_users SET foto='{$avatarUser}' WHERE user_id='" . self::$userData['user_id']. "'");
        file_put_contents(self::$avatarFile . $avatarName, $avatar);
    }

    /**
     * Сохранение аватара для гостя
     *
     * @param   string    $avatar
     */
    static function saveAvatarGuest($avatar)
    {
        $avatarName = 'foto_' . md5(self::$userData['gast_name']) . '.' . self::$typeImg[self::$mod_config['type_img']];
        file_put_contents(self::$avatarFile . $avatarName, $avatar);
    }
}