<?php
/**
* Вспомогательный класс с набором функций
*
* @link https://lazydev.pro/
* @author LazyDev <email@lazydev.pro>
**/

namespace LazyDev\Avatar;

class Helper
{
    static $modName = 'avatar_gen';

    /**
     * Условия
     *
     * @param    array   $data
     * @return   string
     **/
    static function checkIf($data)
    {
        if ($data[2] == '=') {
            return $data[$data[1]] == $data[3] ? $data[4] : '';
        }

        if ($data[2] == '!=') {
            return $data[$data[1]] != $data[3] ? $data[4] : '';
        }

        return $data[0];
    }

    /**
    * Склонение слов
    *
    * @param    array    $a    [0 => count, 1 => новост|ь|и|ей]
    * @return   string
    **/
    static function declinationLazy($a = [])
    {
        $a[0] = strip_tags($a[0] );
        $a[0] = str_replace(' ', '', $a[0]);

        $a[0] = intval($a[0]);
        $words = explode('|', trim($a[1]));
        $parts_word = [];

        switch (count($words)) {
            case 1:
                $parts_word[0] = $words[0];
                $parts_word[1] = $words[0];
                $parts_word[2] = $words[0];
                break;
            case 2:
                $parts_word[0] = $words[0];
                $parts_word[1] = $words[0] . $words[1];
                $parts_word[2] = $words[0] . $words[1];
                break;
            case 3: 
                $parts_word[0] = $words[0];
                $parts_word[1] = $words[0] . $words[1];
                $parts_word[2] = $words[0] . $words[2];
                break;
            case 4: 
                $parts_word[0] = $words[0] . $words[1];
                $parts_word[1] = $words[0] . $words[2];
                $parts_word[2] = $words[0] . $words[3];
                break;
        }

        $word = $a[0] % 10 == 1 && $a[0] % 100 != 11 ? $parts_word[0] : ($a[0] % 10 >= 2 && $a[0] % 10 <= 4 && ($a[0] % 100 < 10 || $a[0] % 100 >= 20) ? $parts_word[1] : $parts_word[2]);

        return $word;
    }

    /**
    * Разбор serialize строки
    *
    * @param    string   $data_form
    * @return   array
    **/
    static function unserializeJs($data_form)
    {
        $new_array = [];
        if ($data_form) {
            parse_str($data_form, $array_post);

            foreach ($array_post as $index => $item) {
                if (is_array($item)) {
                    foreach ($item as $key => $value) {
                        if (is_array($value)) {
                            foreach ($value as $k => $v) {
                                if ($v != '' && $v != '-') {
                                    $new_array[$index][$key][] = self::typeValue($v);
                                }
                            }
                        } elseif ($value != '' && $value != '-') {
                            $new_array[$index][$key] = self::typeValue($value);
                        }
                    }
                } elseif ($item != '' && $item != '-') {
                    $new_array[$index] = self::typeValue($item);
                }
            }
        }
        
        return $new_array;
    }

    /**
     * Разбор массива
     *
     * @param    array   $arr
     * @return   array
     **/
    static function unsetEmpty($arr)
    {
        foreach ($arr as $key => $value) {
            if (is_array($value)) {
                $arr[$key] = self::unsetEmpty($arr[$key]);
            }

            if (empty($value) || $value == '-') {
                unset($arr[$key]);
            } else {
                $arr[$key] = self::typeValue($arr[$key]);
            }
        }

        return $arr;
    }

    
    /**
    * Типизация данных
    *
    * @param    mixed   $v
    * @return   float|int|string
    **/
    static function typeValue($v)
    {
        if (is_numeric($v)) {
            if (is_float($v)) {
                $v = floatval($v);
            } else {
                $v = intval($v);
            }
        } else {
            $v = strip_tags(stripslashes($v));
        }
        
        return $v;
    }
    
    /**
    * Json для js
    *
    * @param    array   $v
    * @return   string
    **/
    static function json($v)
    {
        return json_encode($v, JSON_UNESCAPED_UNICODE);
    }
    
    /**
    * Получить данные с массива по массиву ключей
    *
    * @param    array   $a
    * @param    array   $k
    * @param    int     $c
    * @return   string
    **/
    static public function multiArray($a, $k, $c)
    {
        return ($c > 1) ? self::multiArray($a[$k[count($k) - $c]], $k, ($c - 1)) : $a[$k[(count($k) - 1)]];
    }

    /**
     * Очистить строку для запроса в базу данных
     *
     * @param    string   $v
     * @return   string
     **/
    static function cleanString($v)
    {
        global $db;
        return $db->safesql(strip_tags(stripslashes($v)));
    }

    /**
     * Очистить строку для запроса в базу данных
     *
     * @param    int   $v
     * @return   int
     **/
    static function cleanInt($v)
    {
        return intval($v);
    }

    /**
     * Преобразовывает массив в строку доп полей
     *
     * @param    array   $a
     * @return   string
     **/
    static function xfield($a)
    {
        global $db;

        $f = [];
        foreach ($a as $n => $v) {
            if ($n === '') {
                continue;
            }

            $n = str_replace(['|', '\r\n'], ['&#124;', '__NEWL__'], $n);
            $v = str_replace(['|', '\r\n'], ['&#124;', '__NEWL__'], $v);
            $f[] = $n . '|' . $v;
        }

        return count($f) ? $db->safesql(implode('||', $f)) : '';
    }
}
